pub struct Dataset { /* private fields */ }Expand description
A validated dataset loaded from a bundle conforming to dataset_spec.md.
Implementations
Sourceimpl Dataset
impl Dataset
Sourcepub fn new(
measurements: MeasurementStack,
configuration: SimulationConfiguration,
) -> Result<Self>
pub fn new( measurements: MeasurementStack, configuration: SimulationConfiguration, ) -> Result<Self>
Constructs a dataset from already-loaded values.
pub fn measurements(&self) -> &MeasurementStack
Sourcepub fn source_path(&self) -> Option<&Path>
pub fn source_path(&self) -> Option<&Path>
Root directory of the loaded bundle, or None for programmatic data.
pub fn configuration(&self) -> &SimulationConfiguration
pub fn ground_truth_object(&self) -> Option<&Array2<Complex64>>
pub fn valid_object_mask(&self) -> Option<&Array2<u8>>
pub fn provenance(&self) -> &BTreeMap<String, String>
pub fn measurement_units(&self) -> Option<&str>
pub fn reconstruction_problem( &self, ) -> Result<ReconstructionProblem<MeasurementStack>>
pub fn subset(&self) -> DatasetSubsetBuilder<'_>